summaryrefslogtreecommitdiff
path: root/sw/source/filter/ww8/writerhelper.cxx
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2016-09-07 13:10:40 +0200
committerNoel Grandin <noel@peralex.com>2016-09-08 09:23:40 +0200
commit847e004e65ec3c35acff607588d15cd75a84f121 (patch)
tree1b2ac62948c9ad15d2f231b56eb45ff341f572f7 /sw/source/filter/ww8/writerhelper.cxx
parent3cac15856ade9fce161a49212c9d1861741122a5 (diff)
convert nsRedlineMode_t to typed_flags
including fixing a bug in SwXMLExport::exportDoc where it was ORing with a constant from a different type: nsRedlineType_t::REDLINE_INSERT Change-Id: I2bb154c9a35d106e64fd1a8b6e928d0384c9fafe
Diffstat (limited to 'sw/source/filter/ww8/writerhelper.cxx')
-rw-r--r--sw/source/filter/ww8/writerhelper.cxx10
1 files changed, 5 insertions, 5 deletions
diff --git a/sw/source/filter/ww8/writerhelper.cxx b/sw/source/filter/ww8/writerhelper.cxx
index 0d40c37639de..54c04acdbbce 100644
--- a/sw/source/filter/ww8/writerhelper.cxx
+++ b/sw/source/filter/ww8/writerhelper.cxx
@@ -126,7 +126,7 @@ namespace
if (const SwPosition* pAnchor = rEntry.GetAnchor().GetContentAnchor())
{
// the anchor position will be invalidated by SetRedlineMode
// so set a dummy position and fix it in UpdateFramePositions
SwPosition const dummy(SwNodeIndex(
const_cast<SwNodes&>(pAnchor->nNode.GetNodes())));
@@ -760,8 +760,8 @@ namespace sw
(*aRegion.GetPoint() != *aRegion.GetMark())
)
{
- mrDoc.getIDocumentRedlineAccess().SetRedlineMode((RedlineMode_t)(nsRedlineMode_t::REDLINE_ON | nsRedlineMode_t::REDLINE_SHOW_INSERT |
- nsRedlineMode_t::REDLINE_SHOW_DELETE));
+ mrDoc.getIDocumentRedlineAccess().SetRedlineFlags(RedlineFlags::On | RedlineFlags::ShowInsert |
+ RedlineFlags::ShowDelete);
const SwFltRedline *pFltRedline = static_cast<const SwFltRedline*>
(pEntry->pAttr);
@@ -783,8 +783,8 @@ namespace sw
aRegion.DeleteMark();
*aRegion.GetPoint() = SwPosition(SwNodeIndex(mrDoc.GetNodes()));
mrDoc.getIDocumentRedlineAccess().AppendRedline(pNewRedline, true);
- mrDoc.getIDocumentRedlineAccess().SetRedlineMode((RedlineMode_t)(nsRedlineMode_t::REDLINE_NONE | nsRedlineMode_t::REDLINE_SHOW_INSERT |
- nsRedlineMode_t::REDLINE_SHOW_DELETE ));
+ mrDoc.getIDocumentRedlineAccess().SetRedlineFlags(RedlineFlags::NONE | RedlineFlags::ShowInsert |
+ RedlineFlags::ShowDelete );
}
delete pEntry;
}
@@ -126,7 +126,7 @@ namespace
if (const SwPosition* pAnchor = rEntry.GetAnchor().GetContentAnchor())
{
- // the anchor position will be invalidated by SetRedlineMode
+ // the anchor position will be invalidated by SetRedlineFlags
// so set a dummy position and fix it in UpdateFramePositions
SwPosition const dummy(SwNodeIndex(